@@ -4,7 +4,7 @@ use AnyEvent::HTTP;
 use AnyEvent::Util qw(guard);
 use base qw(Exporter);
 our @EXPORT = qw(mxhr_get);
-our $VERSION = '0.00002';
+our $VERSION = '0.00003';
 
 sub mxhr_get ($@) {
     my $cb = pop;
@@ -69,7 +69,7 @@ sub mxhr_get ($@) {
                 my $headers = $1;
 
                 my %headers = map {
-                    my ($n, $v) = split(/:/, $_, 2);
+                    my ($n, $v) = split(/:\s*/, $_, 2);
                     # lower case it to align with the rest of AE::HTTP
                     $n = lc $n;
                     ($n, $v);
